package com.couchbase.test.constants;

/**
 * Enumeration of Error Constants.
 */
public enum ErrorConstants {

  /* =========== Couchbase Error Constants ============ */

  /**
   * Error constant representing Document doesn't Exists.
   */
  DOCUMENT_DOES_NOT_EXIST("100", "The document does not exist"),

  /**
   * Error constant representing Json Processing Error.
   */
  JSON_PROCESSING_ERROR("101", "Json Processing Error");

  /**
   * Code representing the error constant.
   */
  private final String errorCode;

  /**
   * Message describing the error constant.
   */
  private final String errorMessage;

  /**
   * Constructor to initialize the error code and error message for each member.
   *
   * @param errorCode    Code representing the error constant
   * @param errorMessage Message describing the error constant
   */
  ErrorConstants(String errorCode, String errorMessage) {
    this.errorCode = errorCode;
    this.errorMessage = errorMessage;
  }

  /**
   * Returns the error code for the error constant.
   */
  public String getErrorCode() {
    return this.errorCode;
  }

  /**
   * Returns the error message for the error constant.
   */
  public String getErrorMessage() {
    return this.errorMessage;
  }

}
