package com.couchbase.test.provider;

import com.couchbase.test.model.DataDto;
import com.couchbase.test.utils.CouchbaseStorageUtility;
import com.couchbase.test.utils.JsonUtility;
import com.fasterxml.jackson.core.JsonProcessingException;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import java.util.HashMap;
import java.util.Map;

@Service
public class CouchbaseProvider {
  // Creating an instance of CouchbaseStorageUtilityImpl
  CouchbaseStorageUtility couchbaseStorageUtility;

  public CouchbaseProvider(CouchbaseStorageUtility couchbaseStorageUtility) {
    this.couchbaseStorageUtility = couchbaseStorageUtility;
  }

  public Mono<DataDto> getRecordById(String dataId) {
    String couchbaseDocumentId = "test-document";

    Map<String, Object> params = new HashMap<>();
    params.put("dataId", dataId);

    String getRecordByIdQuery =
        "SELECT record.id, record.records, record.category, record.type FROM data " +
            "USE KEYS [\"test-document\"] UNNEST information AS record WHERE record.id = $dataId";

    try {
      String stringParams = JsonUtility.mapToJson(params);
      Flux<DataDto> couchbaseResponse = couchbaseStorageUtility.executeQuery(
          getRecordByIdQuery,
          stringParams,
          DataDto.class,
          "data");
      Mono<DataDto> dataDto = couchbaseResponse.next();
      return dataDto.switchIfEmpty(Mono.error(new Exception(
          "Not Found")));
    } catch (JsonProcessingException exception) {
      return Mono.error(new Exception("Json Processing Error"));
    }
  }
}
