package com.couchbase.test.utils;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;

import java.io.IOException;

/**
 * Contains utility methods for handling Json content.
 */
public class JsonUtility {

  /**
   * Static member for reading and writing JSON , either to and from basic POJOs.
   */
  private static final ObjectMapper objectMapper;

  /**
   * Logger instance for the class.
   */
  private static final LoggingUtility logger = new LoggingUtility(JsonUtility.class);

  /**
   * Initializes static members.
   */
  static {
    objectMapper = new ObjectMapper();
  }

  /**
   * Creates JSON from Java objects.
   *
   * @return String
   * @Param object - Java object to convert into JSON
   */
  public static String mapToJson(Object object) throws JsonProcessingException {
    logger.logEntry("mapToJson");
    String json = objectMapper.writeValueAsString(object);
    logger.logExit("mapToJson");
    return json;
  }

  /**
   * Creates Java objects from JSON.
   * Overloaded method of mapToObject for the provided json.
   *
   * @return object of provided classtype
   * @Param json - String json
   * @Param classType - Classtype to map the json with
   */
  public static <T> T mapToObject(String json, Class<T> classType)
      throws JsonProcessingException {
    logger.logEntry("mapToObject");
    T object = objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES,
        false).readValue(json, classType);
    logger.logExit("mapToObject");
    return object;
  }
}
