package com.couchbase.test.utils;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Logger class.
 */
public class LoggingUtility {
  private final String className;
  private final String classKey = "CLASS";
  private final String method = "METHOD";
  private final String message = "MESSAGE";
  private final String service = "SERVICE";
  private Logger logger;

  /**
   * Construct LoggingUtility and initialize logger.
   *
   * @param clazz Instance of the class using the logger
   */
  public <T> LoggingUtility(Class<T> clazz) {
    this.logger = LoggerFactory.getLogger(clazz);
    String fullyQualifiedClassName = this.logger.getName();
    String[] classNameParts = fullyQualifiedClassName.split("\\.");
    this.className = classNameParts[classNameParts.length - 1];
  }

  /**
   * Logs a message at the INFO level.
   *
   * @param methodName  Name of the method calling the logger
   * @param displayText Message to display
   */
  public void logInfo(String methodName, String displayText) {
    this.logger.info("From {} => {} ::: {} => {} ::: {} => {}", classKey, this.className,
        method, methodName, message, displayText);
  }

  /**
   * Logs a message at the ERROR level.
   *
   * @param methodName  Name of the method calling the logger
   * @param displayText Message to display
   */
  public void logError(String methodName, String displayText) {
    this.logger.error("From {} => {} ::: {} => {} ::: {} => {}", classKey, this.className,
        method, methodName, message, displayText);
  }

  /**
   * Logs an entry to a method at the DEBUG level.
   *
   * @param methodName Name of the method entered
   */
  public void logEntry(String methodName) {
    this.logger.debug("ENTERED ::: {} => {} ::: {} => {}",
        classKey, this.className, method, methodName);
  }

  /**
   * Logs an exit from a method at the DEBUG level.
   *
   * @param methodName Name of the method exited
   */
  public void logExit(String methodName) {
    this.logger.debug("EXITED ::: {} => {} ::: {} => {}",
        classKey, this.className, method, methodName);
  }
}
